@@ -31,8 +31,6 @@ def sqlacodegen(url, table=None, file=None):
             if field_type:
                 field_module = field_type.__class__.__module__
                 field_class_name = field_type.__class__.__name__
-                if field_class_name == 'INTEGER' and isinstance(column.get("default"), str):
-                    column["default"] = eval(column.get("default"))
                 if field_module not in packages:
                     packages[field_module] = []
                 if field_class_name not in packages[field_module]:
